@@ -27,6 +27,7 @@ summary.xifti <- function(object, ...) {
     out$subcort$labels <- table(object$meta$subcort$labels)
     out$subcort$mask <- dim(object$meta$subcort$mask)
   }
+  out$intent <- object$meta$cifti$intent
   return(out)
 }
 
@@ -36,7 +37,9 @@ summary.xifti <- function(object, ...) {
 #' @inheritParams x_Param_xifti
 #' @method print summary.xifti
 print.summary.xifti <- function(x, ...) {
-  cat("Brain Structures:", paste(names(x$includes)[x$includes], collapse=", "), " \n")
+  cat("Brain Structures:", paste(names(x$includes[seq(3)])[x$includes[seq(3)]], collapse=", "), " \n")
+
+  # [TO DO]: mention medial wall count?
 
   if (x$includes["left cortex"]) {
     cat("\tleft cortex:", x$cortex_left[1], "surface vertices,", 
@@ -57,6 +60,14 @@ print.summary.xifti <- function(x, ...) {
     print(x$subcort$labels)
   }
 
+  if (!is.null(x$intent)) {
+    cat(paste0(
+      "Intent: ", x$intent, " (", 
+      c("dtseries", "dscalar", "dlabel")[match(x$intent, c(3002, 3006, 3007))], 
+      ").\n"
+    ))
+  }
+
   cat("\n")
 }
 
@@ -146,4 +157,72 @@ unmask_cortex <- function(cortex, mwall, mwall_fill=NA) {
   cdat <- matrix(mwall_fill, nrow=length(mwall),  ncol=ncol(cortex))
   cdat[mwall,] <- cortex
   cdat
+}
+
+#' Counts the number of rows (vertices + voxels) in a \code{"xifti"}.
+#' 
+#' Counts the number of data locations in the \code{"xifti"} data. Doesn't bother
+#'  to validate the input.
+#' 
+#' @param xifti The \code{"xifti"} object
+#' @return The number of rows in the \code{"xifti"} data.
+#' 
+#' @keywords internal
+#' 
+nrow_xifti <- function(xifti) {
+  # This function is generic because nrow(xii) will actually use dim(xii)[1]
+  #   which calls this function.
+  bs_present <- !vapply(xifti$data, is.null, FALSE)
+  if (!any(bs_present)) { 
+    return(0)
+  } else {
+    return(sum(vapply(xifti$data[bs_present], nrow, 0)))
+  }
+}
+
+#' Counts the number of columns in a \code{"xifti"}.
+#' 
+#' Counts the number of columns in the \code{"xifti"} data. Doesn't bother
+#'  to validate the input.
+#' 
+#' @param xifti The \code{"xifti"} object
+#' @return The number of columns in the \code{"xifti"} data.
+#' 
+#' @keywords internal
+#' 
+ncol_xifti <- function(xifti) {
+  bs_present <- !vapply(xifti$data, is.null, FALSE)
+  if (!any(bs_present)) { 
+    return(0)
+  } else {
+    return(ncol(xifti$data[[which(bs_present)[1]]]))
+  }
+}
+
+#' Dimensions of a \code{"xifti"}
+#' 
+#' Returns the number of rows and columns in the \code{"xifti"} data. Doesn't
+#'  bother to validate the input.
+#' 
+#' @param x The \code{"xifti"} object
+#' @return The number of rows and columns in the \code{"xifti"} data.
+#' 
+#' @export 
+#' @method dim xifti
+dim.xifti <- function(x) {
+  c(nrow_xifti(x), ncol_xifti(x))
+}
+
+#' Convert a \code{"xifti"} to a matrix
+#' 
+#' Converts a \code{"xifti"} to a matrix. Surfaces and metadata are discarded.
+#' 
+#' @param x The \code{"xifti"} object
+#' @param ... Unused
+#' @return The input as a matrix. Each brainstructure's data is concatenated.
+#' 
+#' @export
+#' @method as.matrix xifti
+as.matrix.xifti <- function(x, ...) {
+  do.call(rbind, x$data)
 }
\ No newline at end of file
